@@ -95,6 +95,8 @@ def edit_section(request, section_id, success_url=None):
     section.save_version(request.user, activity="edit section")
     section.label = request.POST.get('label', '')
     section.slug = slugify(request.POST.get('slug', section.label))[:50]
+    section.show_toc = request.POST.get('show_toc', False)
+    section.deep_toc = request.POST.get('deep_toc', False)
     section.save()
     section.enforce_slug()
     section.save()
